Feed Sharing
------------
Feed sharing is a feature of Adafruit IO which allows you to share your feeds with people you specify.

If you want to share a feed on your Adafruit IO Account with another user, visit the `Sharing a feed page <https://learn.adafruit.com/adafruit-io-basics-feeds/sharing-a-feed>`_ 
on the Adafruit Learning System.

The Adafruit IO Python client supports Feed Sharing in the mqtt_client.py class. 

Usage Example
~~~~~~~~~~~~~


.. literalinclude:: ../examples/mqtt/mqtt_shared_feeds.py